@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: notify.c,v 1.9 2004/02/18 12:49:22 lukasz Exp $
+ *  $Id: notify.c,v 1.10 2004/06/15 10:37:57 alec Exp $
  */
 
 #include <stdio.h>
@@ -117,7 +117,7 @@ void reload(GLOBAL *g, struct notify_module *n)
 						
 							unsigned char *select, *date, *value, *comment, *last_ten, *temp, *temp2;
 					
-							select = strdup("SELECT value, comment, time FROM cash WHERE userid = %id ORDER BY time LIMIT 10");
+							select = strdup("SELECT comment, time, CASE WHEN type=4 THEN value*-1 ELSE value END AS value FROM cash WHERE userid = %id ORDER BY time LIMIT 10");
 							g->str_replace(&select, "%id", g->db_get_data(res,i,"id"));
 						
 							if( (result = g->db_query(select))!=NULL ) {
