@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Sysinfo.class.php,v 1.13 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: Sysinfo.class.php,v 1.14 2004/07/28 06:32:35 alec Exp $
  */
 
 /*
@@ -124,71 +124,31 @@ class Sysinfo {
 		// Uptime function.
 		// Taken afair from PHPSysinfo
 		// Untested on *BSD. Can anyone chek this out on *BSD machine? Thanx.
-		
+				
 		switch (PHP_OS)
 		{
-			
 			case "Linux":
 				$fd = fopen('/proc/uptime', 'r');
 				$ar_buf = split(' ', fgets($fd, 4096));
 				fclose($fd);
 				$sys_ticks = trim($ar_buf[0]);
-				$min   = $sys_ticks / 60;
-				$hours = $min / 60;
-				$days  = floor($hours / 24);
-				$hours = floor($hours - ($days * 24));
-				$min   = floor($min - ($days * 60 * 24) - ($hours * 60));
-				if ($days != 0)
-					$result = "$days dni ";
-				if ($hours != 0)
-					$result .= "$hours godzin ";
-				$result .= "$min minut";
+				$result = uptimef($sys_ticks);
 			break;
 			case "FreeBSD":
 				$s = explode(' ', $this->bsd_grab_key('kern.boottime'));
 				$a = ereg_replace('{ ', '', $s[3]);
 				$sys_ticks = time() - $a;
-				$min   = $sys_ticks / 60;
-				$hours = $min / 60;
-				$days  = floor($hours / 24);
-				$hours = floor($hours - ($days * 24));
-				$min   = floor($min - ($days * 60 * 24) - ($hours * 60));
-				
-				if ( $days != 0 )
-					$result = "$days dni ";
-				if ( $hours != 0 )
-					$result .= "$hours godzin ";
-				$result .= "$min minut";
+				$result = uptimef($sys_ticks);
 			break;
 			case "NetBSD":
 				$a = $this->bsd_grab_key('kern.boottime');
 				$sys_ticks = time() - $a;
-				$min   = $sys_ticks / 60;
-				$hours = $min / 60;
-				$days  = floor($hours / 24);
-				$hours = floor($hours - ($days * 24));
-				$min   = floor($min - ($days * 60 * 24) - ($hours * 60));
-
-				if ( $days != 0 )
-					$result = "$days dni ";
-				if ( $hours != 0 )
-					$result .= "$hours godzin ";
-				$result .= "$min minut";
+				$result = uptimef($sys_ticks);
 			break;
 			case "OpenBSD":
 				$a = $this->bsd_grab_key('kern.boottime');
 				$sys_ticks = time() - $a;
-				$min   = $sys_ticks / 60;
-				$hours = $min / 60;
-				$days  = floor($hours / 24);
-				$hours = floor($hours - ($days * 24));
-				$min   = floor($min - ($days * 60 * 24) - ($hours * 60));
-
-				if ( $days != 0 )
-					$result = "$days dni ";
-				if ( $hours != 0 )
-					$result .= "$hours godzin ";
-				$result .= "$min minut";
+				$result = uptimef($sys_ticks);
 			break;
 			default:
 				$result = "nieznany os (".PHP_OS.")";
