@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accesstable.php,v 1.26 2004/07/02 19:45:23 alec Exp $
+ *  $Id: accesstable.php,v 1.29 2004/07/14 13:28:49 alec Exp $
  */
 
 // lista moduw ktre zawsze s dostpne dla kadego
@@ -44,7 +44,7 @@ $access[table][4][name]         = "przeadowywanie konfiguracji";
 $access[table][4][allow_reg]    = "^reload$";
 
 $access[table][5][name]		= "manipulacja kontami uytkownikw";
-$access[table][5][allow_reg]	= "^(user(add|edit|del)|nodewarn|usergroup(add|edit|delete|move))$";
+$access[table][5][allow_reg]	= "^(user(add|edit|del|assignments)|nodewarn|usergroup(add|edit|delete|move))$";
 
 $access[table][6][name]		= "manipulacja danymi komputerw";
 $access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set|warn)|choose(mac|ip))$";
@@ -55,8 +55,11 @@ $access[table][7][allow_reg]    = "^traffic$";
 $access[table][8][name]         = "dostp do korespondencji seryjnej";
 $access[table][8][allow_reg]    = "^(mailing|mailingsend)$";
 
-$access[table][9][name]         = "dostp do Helpdesku (RT)";
-$access[table][9][allow_reg]    = "^((rtqueue|rtticket)(add|del|edit|info|view|list))$";
+$access[table][9][name]         = "zarzdzanie Helpdeskiem (RT)";
+$access[table][9][allow_reg]    = "^(rtsearch|(rtqueue|rtticket|rtmessage)(add|del|edit|info|view|list))$";
+
+$access[table][10][name]        = "obsuga Helpdesku (RT)";
+$access[table][10][allow_reg]   = "^(rtsearch|rtqueue(list|info|view)|(rtticket|rtmessage)(add|edit|info|view))$";
 
 $access[table][253][name]	= "brak dostpu do modyfikacji i zakadania nowych kont administratorw";
 $access[table][253][deny_reg]	= "^(admin(add|del|edit|passwd))$";
