@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.60 2004/03/14 21:41:33 lukasz Exp $
+ *  $Id: common.php,v 1.62 2004/07/28 06:32:35 alec Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -31,13 +31,11 @@
 // ie $program = execute_program('netstat', '-anp | grep LIST');
 // NOT $program = execute_program('netstat', '-anp|grep LIST');
 
-
 function bsd_grab_key ($key)
 {
 	return execute_program('sysctl', '-n '.$key);
 }
 
-
 function find_program ($program)
 {
 	$path = array('/bin', '/sbin', '/usr/bin', '/usr/sbin', '/usr/local/bin', '/usr/local/sbin');
@@ -57,7 +55,6 @@ function execute_program ($program, $args = '')
 	$buffer = '';
 	$program = find_program($program);
 
-
 	if (!$program) { return; }
 
 	// see if we've gotten a |, if we have we need to do patch checking on the cmd
@@ -88,93 +85,74 @@ function execute_program ($program, $args = '')
 	}
 }
 
+function uptimef($ts)
+{
+	if($ts==0)
+		return "n/a";
+	$min= $ts / 60;
+	$hours = $min / 60;
+	$days  = floor($hours / 24);
+	$hours = floor($hours - ($days * 24));
+	$min= floor($min - ($days * 60 * 24) - ($hours * 60));
+	if ($days != 0)
+	{
+		$result = $days;
+		if($days==1)
+			$result .= ' dzie ';
+		else
+			$result .= ' dni ';
+	}
+	if ($hours != 0) 
+	{
+		$result .= $hours;
+		if($hours==1)
+			$result .= ' godzina ';
+		elseif(in_array($hours, array(2,3,4,22,23)))
+			$result .= ' godziny ';
+		else	
+			$result .= ' godzin ';
+	}
+	if($min != 0)
+	{
+		$result .= $min;
+		if($min==1)
+			$result .= ' minuta ';
+		elseif(in_array($min, array(2,3,4,22,23,24,32,33,34,42,43,44,52,53,54)))
+			$result .= ' minuty ';
+		else
+			$result .= ' minut ';
+	}
+	return $result;
+}
+
 function uptime()
 {
-
-	// Uptime function.
-	// Taken afair from PHPSysinfo
-	// Untested on *BSD. Can anyone chek this out on *BSD machine? Thanx.
+	// Uptime function. Taken afair from PHPSysinfo.
 
 	switch (PHP_OS)
 	{
-
 		case 'Linux':
 			$fd = fopen('/proc/uptime', 'r');
 			$ar_buf = split(' ', fgets($fd, 4096));
 			fclose($fd);
 			$sys_ticks = trim($ar_buf[0]);
-			$min= $sys_ticks / 60;
-			$hours = $min / 60;
-			$days  = floor($hours / 24);
-			$hours = floor($hours - ($days * 24));
-			$min= floor($min - ($days * 60 * 24) - ($hours * 60));
-			if ($days != 0)
-				$result = $days.' dni ';
-			if ($hours != 0)
-				$result .= $hours.' godzin ';
-			$result .= $min.' minut';
+			$result = uptimef($sys_ticks);
 		break;
-
 		case 'FreeBSD':
 			$s = explode(' ', bsd_grab_key('kern.boottime'));
 			$a = ereg_replace('{ ', '', $s[3]);
 			$sys_ticks = time() - $a;
-			$min= $sys_ticks / 60;
-			$hours = $min / 60;
-			$days  = floor($hours / 24);
-			$hours = floor($hours - ($days * 24));
-			$min= floor($min - ($days * 60 * 24) - ($hours * 60));
-
-			if ( $days != 0 )
-			{
-				$result = $days.' dni ';
-			}
-
-			if ( $hours != 0 )
-			{
-				$result .= $hours.' godzin ';
-			}
-			$result .= $min.' minut';
+			$result = uptimef($sys_ticks);
 		break;
 		case 'NetBSD':
 			$a = bsd_grab_key('kern.boottime');
 			$sys_ticks = time() - $a;
-			$min= $sys_ticks / 60;
-			$hours = $min / 60;
-			$days  = floor($hours / 24);
-			$hours = floor($hours - ($days * 24));
-			$min= floor($min - ($days * 60 * 24) - ($hours * 60));
-
-			if ( $days != 0 )
-			{
-				$result = $days.' dni ';
-			}
-
-			if ( $hours != 0 )
-			{
-				$result .= $hours.' godzin ';
-			}
-			$result .= $min.' minut';
+			$result = uptimef($sys_ticks);
 		break;
 		case 'OpenBSD':
 			$a = bsd_grab_key('kern.boottime');
 			$sys_ticks = time() - $a;
-			$min= $sys_ticks / 60;
-			$hours = $min / 60;
-			$days  = floor($hours / 24);
-			$hours = floor($hours - ($days * 24));
-			$min= floor($min - ($days * 60 * 24) - ($hours * 60));
-
-			if ( $days != 0 )
-			{
-				$result = $days.' dni ';
-			}
-
-			if ( $hours != 0 )
-			{
-				$result .= $hours.' godzin ';
-			}
-			$result .= $min.' minut';
+			$result = uptimef($sys_ticks);
 		break;
 		case 'WINNT':
 //			dl("php_w32api.dll");
@@ -189,15 +167,13 @@ function uptime()
 			}else{
 				$result = 'nieznany (brak w32api)';
 			}
-			break;
+		break;
 		default:
 			$result = 'nieznany os ('.PHP_OS.')';
 		break;
-
 	}
 
 	return $result;
-
 }
 
 function redir($url)
@@ -361,7 +337,6 @@ function check_mac($macaddr)
 
 function textwrap($text, $wrap=76, $break = "\n")
 {
-
 	// This function is takem from newsportal
 
 	$len = strlen($text);
@@ -413,8 +388,8 @@ function isipinstrict($ip,$net,$mask)
 		return false;
 }
 
-function getmicrotime(){
-
+function getmicrotime()
+{
 	// This function has been taken from PHP manual
 
 	list($usec, $sec) = explode(' ',microtime());
@@ -423,7 +398,6 @@ function getmicrotime(){
 
 function writesyslog($message,$type)
 {
-
 	// Untested on *BSD. Can anyone chek this out on *BSD machine? Thanx.
 
 	switch(PHP_OS)
@@ -444,17 +418,13 @@ function writesyslog($message,$type)
 			syslog($type,$message.' (at '.$access.' from '.$_SERVER['REMOTE_ADDR'].' ('.$_SERVER['HTTP_USER_AGENT'].'))');
 
 			closelog();
-
-			break;
-
+		break;
 		default:
-
 			return FALSE;
-			break;
+		break;
 	}
 
 	return TRUE;
-
 }
 
 function rmkdir($dir)
@@ -560,22 +530,19 @@ function check_email( $email )
 }
 
 function check_nip($nip)
-
 {
+	$steps = array(6, 5, 7, 2, 3, 4, 5, 6, 7);
 
-		$steps = array(6, 5, 7, 2, 3, 4, 5, 6, 7);
+	$nip = str_replace('-', '', $nip);
+	$nip = str_replace(' ', '', $nip);
 
-		$nip = str_replace('-', '', $nip);
-		$nip = str_replace(' ', '', $nip);
+	if (strlen($nip) != 10) return FALSE;
 
-		if (strlen($nip) != 10) return FALSE;
+	for ($x = 0; $x < 9; $x++) $sum_nb += $steps[$x] * $nip[$x];
 
-		for ($x = 0; $x < 9; $x++) $sum_nb += $steps[$x] * $nip[$x];
-
-		if ($sum_nb % 11 == $nip[9]) return TRUE;
-
-		return FALSE;
+	if ($sum_nb % 11 == $nip[9]) return TRUE;
 
+	return FALSE;
 }
 
 function check_pesel($pesel)
@@ -621,7 +588,6 @@ function get_producer($mac)
 
 function to_words($num, $power = 0, $powsuffix = '')
 {
-
 	// Extracted from lang.pl.php by Piotr Klaban <makler at man dot torun dot pl>
 	// from PEAR package Number_Words-0.3.1
 
