@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: smarty_addons.php,v 1.15 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: smarty_addons.php,v 1.19 2004/03/14 20:28:44 lukasz Exp $
  */
 
 // Funkcje dodatkowe, do roszerzenia Smarty.
@@ -51,8 +51,14 @@ function _smarty_function_confirm($args, &$SMARTY)
 	$text = str_replace("\r",'',$text);
 	$text = str_replace("\n",'\n',$text);
 
-	if($text != "")
-		return ' onClick="return confirmLink(this, \''.$text.'\')" ';
+	if($text != '')
+		$ret = ' onClick="return confirmLink(this, \''.$text.'\')" ';
+	if($args['href'] != '')
+		$ret .= ' href="'.$args['href'].'" ';
+//		$ret .= ' href="?m=confirm&text='.urlencode($text).'&link='.urlencode($args['href']).'" ';
+		
+	$ret = eregi_replace('[ ]+', ' ', $ret);
+	return $ret;
 }
 
 function _smarty_function_tip($args, &$SMARTY)
@@ -114,5 +120,7 @@ $SMARTY->register_function('tip','_smarty_function_tip');
 $SMARTY->register_function('confirm','_smarty_function_confirm');
 $SMARTY->register_modifier('to_words','to_words');
 $SMARTY->register_modifier('striphtml','_smarty_modifier_striphtml');
-
+$SMARTY->assign('now', time());
+$SMARTY->assign('tomorrow', time()+86400);
+$SMARTY->assign('yesterday', time()-86400);
 ?>
