@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,13 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailing.php,v 1.24 2004/04/22 19:31:08 alec Exp $
+ *  $Id: mailing.php,v 1.25 2004/07/12 17:16:36 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Mailing";
 
 $SMARTY->assign('networks', $LMS->GetNetworks());
 $SMARTY->assign('usergroups', $LMS->UsergroupGetAll());
+$SMARTY->assign('admininfo', $LMS->GetAdminInfo($SESSION->id));
 $SMARTY->display('mailing.html');
 
 ?>
