@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevdel.php,v 1.8 2004/03/11 17:24:22 lukasz Exp $
+ *  $Id: netdevdel.php,v 1.9 2004/06/24 20:22:05 alec Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
@@ -36,7 +36,7 @@ $SMARTY->assign('netdevid',$_GET['id']);
 if($LMS->CountNetDevLinks($_GET['id'])>0)
 {
 	$body = "<H1>".$layout['pagetitle']."</H1>";
-	$body .= "<P>Nie mona usun urzdzenia ktre jest podczone do innych urzdze.</P>";
+	$body .= "<P>Nie mona usun urzdzenia ktre jest podczone do innych urzdze lub komputerw.</P>";
 }else{
     if($_GET['is_sure']!=1)
     {
