@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeinfo.php,v 1.32 2004/04/18 08:45:09 chilek Exp $
+ *  $Id: nodeinfo.php,v 1.33 2004/07/15 06:04:40 alec Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
@@ -47,6 +47,13 @@ elseif($LMS->GetNodeOwner($_GET['id']) == 0)
 	die;
 }
 
+if($_GET['devid'])
+{
+	$error['netdev'] = 'Brak wolnych portw w wybranym urzdzeniu!';
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('netdevice', $_GET['devid']);
+}
+
 $nodeid = $_GET['id'];
 $ownerid = $LMS->GetNodeOwner($nodeid);
 $tariffs = $LMS->GetTariffs();
