@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,22 +21,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentlist.php,v 1.3 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: paymentlist.php,v 1.5 2004/03/11 17:24:22 lukasz Exp $
  */
 
-$layout['pagetitle']="Lista opat staych";
+$layout['pagetitle'] = "Lista opat staych";
 
 $paymentlist = $LMS->GetPaymentList();
 
 $listdata['total'] = $paymentlist['total'];
 
-unset($paymentlist[total]);
+unset($paymentlist['total']);
 
-$_SESSION['backto'] = $_SERVER[QUERY_STRING];
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$SMARTY->assign("paymentlist",$paymentlist);
-$SMARTY->assign("listdata",$listdata);
-$SMARTY->assign("layout",$layout);
-$SMARTY->display("paymentlist.html");
+$SMARTY->assign('paymentlist',$paymentlist);
+$SMARTY->assign('listdata',$listdata);
+$SMARTY->display('paymentlist.html');
 
 ?>
