@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3-cvs
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,17 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: reload.php,v 1.20 2003/12/04 04:39:14 lukasz Exp $
+ *  $Id: reload.php,v 1.26 2004/02/21 19:38:17 lukasz Exp $
  */
 
 // Agggrrr. Nie zwracajcie uwagi na styl pisania *TEGO* kawaka kodu :)
 // Jest 7:35 a ja ca noc nie spaem :)
 
-$layout[$pagetitle]="Przeadowanie ustawie";
+$layout[$pagetitle]="Przeadowanie konfiguracji";
 
-$SMARTY->display("header.html");
+$SMARTY->display('header.html');
 
-?><H1>Przeadowanie ustawie</H1><?php
+?><H1>Przeadowanie konfiguracji</H1><?php
 
 $_RELOAD_TYPE = $LMS->CONFIG['phpui']['reload_type'];
 $_EXECCMD = $LMS->CONFIG['phpui']['reload_execcmd'];
@@ -72,9 +72,15 @@ switch($_RELOAD_TYPE)
 			}else
 				if($reloadtimestamp = $LMS->GetTS("_force"))
 				{
-					echo 'Wykryto zlecenie przeadowania konfiguracji z '.date("Y/m/d H:i",time()).'.<BR>';
-					echo 'Kliknij <A HREF="?m=reload&cancel">tutaj</a> aby anulowa to zlecenie.';
-				}else{
+					if(!isset($_GET['refresh'])) 
+					{					
+						echo 'W bazie danych wykryto zlecenie przeadowania z '.date("d.m.Y H:i",$reloadtimestamp).'.<BR>';
+						echo 'Moesz je <A HREF="?m=reload&cancel">anulowa</A> lub <A HREF="?m=reload&refresh">ponowi</A>.';
+					} else {
+						echo 'Zapisano zlecenie przeadowania konfiguracji w bazie danych.';
+						$LMS->SetTS("_force");
+					}
+				} else {
 					echo 'Zapisano zlecenie przeadowania konfiguracji w bazie danych.';
 					$LMS->SetTS("_force");
 				}
@@ -88,26 +94,6 @@ switch($_RELOAD_TYPE)
 
 }
 
-$SMARTY->display("footer.html");
+$SMARTY->display('footer.html');
 
-/*
- * $Log: reload.php,v $
- * Revision 1.20  2003/12/04 04:39:14  lukasz
- * - porzdki
- * - troch podubane przy parsowaniu pliku konfiguracyjnego
- *
- * Revision 1.19  2003/09/07 18:46:57  lexx
- * - die ADOB, die!
- *
- * Revision 1.18  2003/08/31 19:05:14  lukasz
- * - 19:48.32| < Lexx__> Baseciq, ten tego w reload.php uzywasz sqlTSfmt() ktore jest zdaje sie obsolete
- *
- * Revision 1.17  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.16  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
