@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3-cvs
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,20 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: setlang.php,v 1.4 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: setlang.php,v 1.8 2004/02/21 19:38:17 lukasz Exp $
  */
 
-	$LMS->SetAdminLang($SESSION->id,$_GET[lang]);
-	header("Location: ?m=welcome");
+$LMS->SetAdminLang($SESSION->id,$_GET['lang']);
+
+header("Location: ?m=welcome");
 
-/*
- * $Log: setlang.php,v $
- * Revision 1.4  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.3  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
\ No newline at end of file
