@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3-cvs
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useradd.php,v 1.41 2003/12/04 04:39:14 lukasz Exp $
+ *  $Id: useradd.php,v 1.47 2004/03/11 21:06:50 alec Exp $
  */
 
 $useradd = $_POST['useradd'];
@@ -53,10 +53,10 @@ elseif(isset($useradd))
 	if($useradd['zip'] !='' && !eregi('^[0-9]{2}-[0-9]{3}$',$useradd['zip']))
 		$error['zip'] = 'Podany kod pocztowy jest bdny!';
 
-	if($useradd['gguin'] == 0)
-		unset($useradd['gguin']);
+	if($useradd['gguin'] == '')
+		$useradd['gguin'] = 0;
 
-	if($useradd['gguin'] !='' && !eregi('^[0-9]{4,}$',$useradd['gguin']))
+	if($useradd['gguin'] !=0 && !eregi('^[0-9]{4,}$',$useradd['gguin']))
 		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
 	
 	if(!$error)
@@ -81,51 +81,10 @@ if(!isset($useradd['city']))
 if(!isset($useradd['address']))	
 	$useradd['address'] = $LMS->CONFIG['phpui']['default_address'];
 
-$layout['pagetitle']='Nowy uytkownik';
+$layout['pagetitle'] = 'Nowy uytkownik';
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('useradd',$useradd);
 $SMARTY->assign('error',$error);
 $SMARTY->display('useradd.html');
 
-/*
- * $Log: useradd.php,v $
- * Revision 1.41  2003/12/04 04:39:14  lukasz
- * - porzdki
- * - troch podubane przy parsowaniu pliku konfiguracyjnego
- *
- * Revision 1.40  2003/12/04 03:43:51  lukasz
- * - dodany PESEL do rekordu uytkownika, upgrade bazy
- *   Jeeli uytkownik nie posiada NIPu, to wtedy na fakturze umieszczany jest
- *   PESEL.
- * - do faktur zostao dodane miejsce wystawienia
- * - zamiana nazewctwa w tabelach z 'sww' na 'pkwiu'
- * - przegenerowane doce
- * - TODO: jeeli na fakturze nie ma pozycji z pkwiu, to usun t kolumen
- *   z faktury.
- * - w choler kosmetyki
- *
- * Revision 1.39  2003/11/22 17:32:12  alec
- * poprawka http://lists.rulez.pl/lms/1482.html
- *
- * Revision 1.38  2003/11/22 17:11:58  alec
- * po co tu GetTariffs?
- *
- * Revision 1.37  2003/09/09 01:22:28  lukasz
- * - nowe finanse
- * - kosmetyka
- * - bugfixy
- * - i inne rzeczy o ktrych aktualnie nie pamitam
- *
- * Revision 1.36  2003/09/05 13:11:24  lukasz
- * - nowy sposb wywietlania informacji o bdach
- *
- * Revision 1.35  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.34  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
